==> jc-1.4.0.tar.gz: gnu/xml/aelfred2/JAXPFactory__24JaxpParser.h <==
// class gnu.xml.aelfred2.JAXPFactory$JaxpParser

// class file dependencies
// @dep_class b3af6c0bca376c21 gnu_xml_aelfred2_JAXPFactory__24JaxpParser
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8d3180c29ab6d2bd javax_xml_parsers_SAXParser

// header file dependencies
// @dep_header javax_xml_parsers_SAXParser

#include "javax/xml/parsers/SAXParser.h"

#ifndef _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_
#define _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_

// Forward structure declarations
struct _jc_gnu_xml_aelfred2_XmlReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;
struct _jc_org_xml_sax_XMLReader$object;
struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object;

// Typedefs
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object;

typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype;

// Constructors
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getParser$5ccc935c216d978f(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getXMLReader$2d78777e030cb408(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$isNamespaceAware$a8b751f0cad64593(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$isValidating$c40ecdd1e5e6c7a7(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$setProperty$a4769aed759cc4ba(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getParser$5ccc935c216d978f;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getProperty$ad67146a826fdaf8;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getXMLReader$2d78777e030cb408;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$isNamespaceAware$a8b751f0cad64593;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$isValidating$c40ecdd1e5e6c7a7;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$setProperty$a4769aed759cc4ba;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods {
	struct _jc_object	*(*getParser$5ccc935c216d978f)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getXMLReader$2d78777e030cb408)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
	jboolean	(*isNamespaceAware$a8b751f0cad64593)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
	jboolean	(*isValidating$c40ecdd1e5e6c7a7)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
	void	(*setProperty$a4769aed759cc4ba)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *);
};

// Vtable
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParser$vmethods	javax_xml_parsers_SAXParser;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
};

// Vtype
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype {
	_jc_type			type;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs {
	struct _jc_gnu_xml_aelfred2_XmlReader$object	*ae2;
	struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object	*parser;
};

// Reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs {
    _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
    _jc_javax_xml_parsers_SAXParser$sub_refs	javax_xml_parsers_SAXParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParser$sub_nonrefs	javax_xml_parsers_SAXParser;
    _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
};

// Object instance structure
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object {
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype	*vtype;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_aelfred2_JAXPFactory__24JaxpParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$class_object;

#endif	/* _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/aelfred2/JAXPFactory__24JaxpParser.h <==
// class gnu.xml.aelfred2.JAXPFactory$JaxpParser

// class file dependencies
// @dep_class 4a0717d1d5dbca87 gnu_xml_aelfred2_JAXPFactory__24JaxpParser
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8d3180c29ab6d2bd javax_xml_parsers_SAXParser

// header file dependencies
// @dep_header javax_xml_parsers_SAXParser

#include "javax/xml/parsers/SAXParser.h"

#ifndef _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_
#define _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_

// Forward structure declarations
struct _jc_gnu_xml_aelfred2_XmlReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;
struct _jc_org_xml_sax_XMLReader$object;
struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object;

// Typedefs
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object;

typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype;

// Constructors
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getParser$5ccc935c216d978f(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getProperty$ad67146a826fdaf8(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$getXMLReader$2d78777e030cb408(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$isNamespaceAware$a8b751f0cad64593(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$isValidating$c40ecdd1e5e6c7a7(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$setProperty$a4769aed759cc4ba(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getParser$5ccc935c216d978f;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getProperty$ad67146a826fdaf8;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$getXMLReader$2d78777e030cb408;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$isNamespaceAware$a8b751f0cad64593;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$isValidating$c40ecdd1e5e6c7a7;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$setProperty$a4769aed759cc4ba;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods {
	struct _jc_object	*(*getParser$5ccc935c216d978f)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getProperty$ad67146a826fdaf8)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getXMLReader$2d78777e030cb408)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
	jboolean	(*isNamespaceAware$a8b751f0cad64593)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
	jboolean	(*isValidating$c40ecdd1e5e6c7a7)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
	void	(*setProperty$a4769aed759cc4ba)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParser$vmethods	javax_xml_parsers_SAXParser;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vmethods	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
};

// Vtype
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype {
	_jc_type			type;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs {
	struct _jc_gnu_xml_aelfred2_XmlReader$object	*ae2;
	struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object	*parser;
};

// Reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs {
    _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_refs	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
    _jc_javax_xml_parsers_SAXParser$sub_refs	javax_xml_parsers_SAXParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParser$sub_nonrefs	javax_xml_parsers_SAXParser;
    _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$sub_nonrefs	gnu_xml_aelfred2_JAXPFactory__24JaxpParser;
};

// Object instance structure
struct _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$object {
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype	*vtype;
	_jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$vtype _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_aelfred2_JAXPFactory__24JaxpParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_aelfred2_JAXPFactory__24JaxpParser$class_object;

#endif	/* _JC_gnu_xml_aelfred2_JAXPFactory__24JaxpParser_H_ */
